@@ -11,7 +11,7 @@ use Exporter qw(import);
  
 our @EXPORT_OK = qw(convert get_units);
 
-our $VERSION = '0.026';
+our $VERSION = '0.027';
 
 sub new {
     my $class = shift;
@@ -260,13 +260,13 @@ sub get_units {
         },
         {
             'unit'      => 'mile',
-            'factor'    => '0.000621371',
-            'aliases'   => ['miles', 'statute mile', 'statute miles', 'land mile', 'land miles'],
+            'factor'    => 1/1609.344,
+            'aliases'   => ['miles', 'statute mile', 'statute miles', 'land mile', 'land miles', 'mi'],
             'type'      => 'length',
         },
         {
             'unit'      => 'yard',
-            'factor'    => '1.09361',
+            'factor'    => '1.0936133',
             'aliases'   => ['yards', 'yd', 'yds', 'yrds'],
             'type'      => 'length',
         },
@@ -1011,7 +1011,7 @@ sub get_units {
         {
             'unit'      => 'square mile',
             'factor'    => 1/258.99881,
-            'aliases'   => ['square miles', 'square statute mile', 'square statute miles', 'square land mile', 'square land miles', 'miles^2', 'miles'],
+            'aliases'   => ['square miles', 'square statute mile', 'square statute miles', 'square land mile', 'square land miles', 'miles^2', 'miles', 'sq mi'],
             'type'      => 'area',
         },
         {
@@ -1141,7 +1141,7 @@ Convert::Pluggable - convert between various units of measurement
 
 =head1 VERSION
 
-Version 0.026
+Version 0.027
 
 =head1 SYNOPSIS
 
@@ -1204,7 +1204,7 @@ This gets some useful metadata for convert() to carry out its work.
 =head2 get_units()
 
 This is where you add new unit types so that convert() can operate on them.  Currently supported units of measurement
-are: mass, length, area, volume, time, pressure, energy, power, angle, force, temperature, digital. 
+are: mass, length, time, pressure, energy, power, angle, force, temperature, digital. 
 
 =head2 parse_number()
 
@@ -1220,6 +1220,12 @@ bradley andersen, C<< <bradley at pvnp.us> >>
 
 =item *
 
+Because of the base unit ('day'), time conversions are off:
+
+e.g.: '1 year to months' yields: '1 year is 11.999 months'
+
+=item *
+
 add back in guard against things like: '10 inches to 5 cm'
 
 =back
